ryvencore.dtypes.dtypes module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.dtypes.dtypes module

This module contains definitions of declarative types which can be conveniently used for data inputs. For each of the exposed types, the frontend can define some prebuilt widgets, which makes nodes from other frontends that use those types to determine input widgets automatically compatible in other environments. This list may grow significantly over time.

class DType(default, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `object`

  static from_str(s)
  add_data(*attr_names)
  get_state() → dict
  set_state(data: dict)

class Data(default=None, size: str = 'm', doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

  Any kind of data represented by some evaluated text input

class Integer(default: int = 0, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Float(default: float = 0.0, bounds: Optional[tuple] = None, decimals: int = 10, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Boolean(default: bool = False, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Char(default: chr = '', doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class String(default: str = '', size: str = 'm', doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Choice(default=None, items: List = [], doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class List(default: List = [], doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Date(default, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Time(default, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Color(default, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`

class Range(default, bounds: Optional[tuple] = None, doc: str = '', _load_state=None)

  Bases: `ryvencore.dtypes.dtypes.DType`